@@ -19,7 +19,7 @@ from bilirpc.bilibili.app.dynamic.v2.dynamic_pb2_grpc import DynamicStub
 from .tools import fakebuvid, make_metadata
 
 
-async def get_follow_dynamic(update_baseline: Optional[str], access_token: str):
+async def get_follow_dynamic(update_baseline: Optional[str]=None, access_token: str=None):
     try:
         async with grpc.aio.secure_channel(
                 "grpc.biliapi.net",
@@ -28,7 +28,7 @@ async def get_follow_dynamic(update_baseline: Optional[str], access_token: str):
             if update_baseline:
                 req = DynAllReq(update_baseline=update_baseline, refresh_type=1)
             else:
-                req = DynAllReq(refresh_type=1)
+                req = DynAllReq()
             resp = await stub.DynAll(req, metadata=make_metadata(buvid=fakebuvid(),
                                                                  access_token=access_token))
             exclude_list = [
